from yupi import Trajectory

def subsample(traj: Trajectory, step=1, step_in_seconds=False):
    """
    Sample the trajectory ``traj`` by removing evenly spaced
    points according to ``step``.

    Parameters
    ----------
    traj : Trajectory
        Input trajectory.
    step : int, optional
        Number of sample points or period, depending on the value
        of ``step_in_seconds``. By default 1.
    step_in_seconds : bool, optional
        If True, ``step`` is considered as the number of sample
        points. Otherwise, ``step`` is interpreted as the sample
        period, in seconds. By default False.

    Returns
    -------
    Trajectory
        Output trajectory.
    """

    if step_in_seconds:
        step = int(step / traj.dt)

    points = traj.r[::step]
    ang = traj.ang[::step] if traj.ang is not None else None
    t = traj.t[::step] if traj.t is not None else None
    return Trajectory(points=points, t=t, ang=ang, dt=step*traj.dt)




LINE = '-'
DOTTED = 'o'
LINE_DOTTED = '-o'

YUPI_COLORS = [
    '#3489b1',
    '#a14383',
    '#e5d935',
    '#af3c3c',
    '#54ac43',
    '#e88d26',
    '#3c4baf'
]

YUPI_LIGHT_COLORS = [
    '#99d2ec',
    '#eaa0d2',
    '#fdf584',
    '#ea8080',
    '#a6ec98',
    '#f7c790'
]

BLUE = YUPI_COLORS[0]
MAGENTA = YUPI_COLORS[1]
YELLOW = YUPI_COLORS[2]
RED = YUPI_COLORS[3]
GREEN = YUPI_COLORS[4]
ORANGE = YUPI_COLORS[5]
MID_BLUE = YUPI_COLORS[6]

LIGHT_BLUE = YUPI_LIGHT_COLORS[0]
LIGHT_MAGENTA = YUPI_LIGHT_COLORS[1]
LIGHT_YELLOW = YUPI_LIGHT_COLORS[2]
LIGHT_RED = YUPI_LIGHT_COLORS[3]
LIGHT_GREEN = YUPI_LIGHT_COLORS[4]
LIGHT_ORANGE = YUPI_LIGHT_COLORS[5]



from yupi.graphics._stats_plots import (
    plot_angles_hist,
    plot_kurtosis,
    plot_msd,
    plot_vacf,
    plot_velocity_hist
)

from yupi.graphics._trajs_plots import plot_2D

from yupi.graphics._style import (
    LINE,
    LINE_DOTTED,
    DOTTED
)

__all__ = [
    'plot_angles_hist',
    'plot_kurtosis',
    'plot_msd',
    'plot_vacf',
    'plot_velocity_hist',
    'plot_2D',
    'LINE',
    'LINE_DOTTED',
    'DOTTED'
]
